@@ -1,4 +1,3 @@
-# -*- encoding: utf-8 -*-
 # Copyright (c) 2016 b<>com
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,8 +15,8 @@
 
 import logging
 
-from django.core import urlresolvers
 from django.template.defaultfilters import title  # noqa
+from django import urls
 from django.utils.translation import pgettext_lazy
 from django.utils.translation import ugettext_lazy as _
 import horizon.exceptions
@@ -62,22 +61,13 @@ class ActionsFilterAction(horizon.tables.FilterAction):
     policy_rules = (("infra-optim", "action:detail"),)
 
 
-def get_next_action_uuid_link(datum):
-    try:
-        return urlresolvers.reverse(
-            "horizon:admin:actions:detail",
-            kwargs={"action_uuid": getattr(datum, "next_uuid", None)})
-    except urlresolvers.NoReverseMatch:
-        return None
-
-
 def get_action_plan_link(datum):
     try:
-        return urlresolvers.reverse(
+        return urls.reverse(
             "horizon:admin:action_plans:detail",
             kwargs={"action_plan_uuid": getattr(
                 datum, "action_plan_uuid", None)})
-    except urlresolvers.NoReverseMatch:
+    except urls.NoReverseMatch:
         return None
 
 
@@ -98,10 +88,6 @@ class ActionsTable(horizon.tables.DataTable):
         'action_plan_uuid',
         verbose_name=_('Action Plan'),
         link=get_action_plan_link)
-    next_action = horizon.tables.Column(
-        'next_uuid',
-        verbose_name=_('Next Action'),
-        link=get_next_action_uuid_link)
 
     def get_object_id(self, datum):
         return datum.uuid
@@ -131,10 +117,6 @@ class RelatedActionsTable(horizon.tables.DataTable):
         'action_plan_uuid',
         verbose_name=_('Action Plan'),
         link=get_action_plan_link)
-    next_action = horizon.tables.Column(
-        'next_uuid',
-        verbose_name=_('Next Action'),
-        link=get_next_action_uuid_link)
 
     def get_object_id(self, datum):
         return datum.uuid
